@@ -80,7 +80,7 @@ public:
     QString getBandNameFromFreq(const double _n);
     double getLowLimitBandFromBandName(const QString _sm);
     double getLowLimitBandFromBandId(const QString _sm);
-    bool isThisFreqInBand(const QString b, const QString fr);
+    bool isThisFreqInBand(const QString _band, const QString _fr);
 
     int getLastQSOid();
     bool addQSOFromWSJTX(const QString _dxcall, const double _freq, const QString _mode,
@@ -199,11 +199,17 @@ public:
     QStringList getPropModeList();
 
     bool clearSatList();
-    bool addSatellite(const QString _arrlId, const QString _name, const QString _downLink, const QString _upLink, const QString _mode);
+    bool addSatellite(const QString _arrlId, const QString _name, const QString _downLink, const QString _upLink, const QString _mode, int id = -1);
+    int getDBSatId(const QString _arrlId);
     QStringList getSatellitesList();   
     QString getSatelliteUplink(const QString _sat);
     QString getSatelliteDownlink(const QString _sat);
     QString getSatelliteMode(const QString _sat);
+    QString getSatelliteFullUplink(const QString _sat);
+    QString getSatelliteFullDownlink(const QString _sat);
+    QString getSatelliteFullMode(const QString _sat);
+    QString getSatelliteName(const QString _sat);
+    QString getSateliteArrlIdFromId(const int _id);
     QStringList getQSLRcvdList();
     QStringList getQSLSentList();
     QStringList getClubLogStatusList();
