@@ -80,8 +80,9 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
     clubLogPage = new SetupPageClubLog(this);
      //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
-    UDPPage = new SetupPageUDP(this);
+    UDPPage = new SetupPageUDP(this);    
     //qDebug() << "SetupDialog::SetupDialog 3.13" << endl;
+    satsPage = new SetupPageSats(dataProxy, this);
 
     //qDebug() << "SetupDialog::SetupDialog 4" << endl;
 
@@ -94,6 +95,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
     tabWidget->addTab(clubLogPage, "ClubLog");
     tabWidget->addTab(UDPPage, "WSJT-X");
+    tabWidget->addTab(satsPage , tr("Satellites"));
 
 
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
@@ -117,7 +119,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->addLayout(horizontalLayout);
     mainLayout->addLayout(buttonsLayout);
-
+    userDataPage->setFocus();
     setLayout(mainLayout);
 
     setWindowTitle(tr("Config Dialog"));
@@ -159,6 +161,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     logsPage = new SetupPageLogs(dataProxy, this);
     clubLogPage = new SetupPageClubLog(this);
     UDPPage = new SetupPageUDP(this);
+    satsPage = new SetupPageSats(dataProxy, this);
 
      //qDebug() << "SetupDialog::SetupDialog 02" << endl;
     tabWidget->addTab(userDataPage, tr("User data"));
@@ -170,6 +173,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
     tabWidget->addTab(clubLogPage, tr("ClubLog"));
     tabWidget->addTab(UDPPage, tr("WSJT-X"));
+    tabWidget->addTab(satsPage , tr("Satellites"));
 
      //qDebug() << "SetupDialog::SetupDialog 03" << endl;
 
@@ -362,7 +366,7 @@ void SetupDialog::changePage(QListWidgetItem *current, QListWidgetItem *previous
 
 void SetupDialog::slotOkButtonClicked()
 {
-qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
+ //qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
 
     if (!miscPage->areDBPathChangesApplied())
     {
@@ -513,6 +517,7 @@ qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
         stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
         stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  endl;
         stream << "CheckNewVersions=" << miscPage->getCheckNewVersions() << ";" <<  endl;
+        stream << "ManageDXMarathon=" << miscPage->getDXMarathon() << ";" <<  endl;
 
         if ((miscPage->getReportInfo()).toUpper() == "TRUE")
         {
@@ -713,6 +718,8 @@ bool SetupDialog::processConfigLine(const QString _line)
         miscPage->setCompleteWithPrevious(value.toLower());
     }else if (tab=="SENDQSLWHENREC"){
         miscPage->setSendQSLWhenRec(value.toLower());
+    }else if (tab=="MANAGEDXMARATHON"){
+        miscPage->setDXMarathon(value.toLower());
     }
     else if (tab=="SHOWCALLSIGNINSEARCH"){
         miscPage->setShowStationCallSignInSearch(value.toLower());
@@ -999,6 +1006,7 @@ void SetupDialog::setDefaults()
     miscPage->setKeepMyData("TRUE");
     miscPage->setCheckNewVersions("TRUE");
     miscPage->setReportInfo("FALSE");
+    miscPage->setDXMarathon("FALSE");
 
     UDPPage->setUDPServer("FALSE");
     UDPPage->setUDPServerPort("2237");
@@ -1098,7 +1106,6 @@ void SetupDialog::checkIfNewBandOrMode()
     _items.removeDuplicates();
     bandModePage->setActiveModes(_items);
      //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << endl;
-
 }
 
 
@@ -1113,7 +1120,6 @@ void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
     }
     userDataPage->setStationQrz(_qs.at(0));
     userDataPage->setOperators(_qs.at(1));
-
 }
 
 void SetupDialog::slotSetStationCallSign(const QString _p)
