@@ -3,7 +3,7 @@
 
 SoftwareUpdate::SoftwareUpdate(const QString _klogVersion) : QObject(0)
 {
-    //qDebugg() << "SoftwareUpdate::SoftwareUpdate(): " << _klogVersion << endl;
+    //qDebug() << "SoftwareUpdate::SoftwareUpdate(): " << _klogVersion << endl;
     util = new Utilities;
 
     updateDialog = new SoftwareUpdateDialog();
@@ -19,7 +19,7 @@ SoftwareUpdate::SoftwareUpdate(const QString _klogVersion) : QObject(0)
     callsign = QString();
     //result = -1;  // Error unknown
     //reply = new QNetworkReply;
-    manager = new QNetworkAccessManager(this);
+    //manager = new QNetworkAccessManager(this);
      //request = new QNetworkRequest(this);    
     //request.setUrl(QUrl("http://localhost"));
     //request.setUrl(QUrl("https://download.savannah.gnu.org/releases/klog/"));
@@ -40,17 +40,17 @@ SoftwareUpdate::~SoftwareUpdate()
 void SoftwareUpdate::setTheURL(QString _url)
 {
     //qDebug() << "SoftwareUpdate::setTheURL: " << _url << endl;
-    request.setUrl(QUrl(_url));
+//    request.setUrl(QUrl(_url));
 }
 
 void SoftwareUpdate::setVersion(const QString _klogVersion)
 {
-    //qDebugg() << "SoftwareUpdate::setVersion: " << _klogVersion << endl;
+    //qDebug() << "SoftwareUpdate::setVersion: " << _klogVersion << endl;
     klogVersion = _klogVersion;
-
     latestVersion = klogVersion;
 
     setHeader();
+    //qDebug() << "SoftwareUpdate::setVersion: END "  << endl;
 }
 
 void SoftwareUpdate::slotReadyRead()
@@ -65,10 +65,10 @@ void SoftwareUpdate::slotError(int _p)
 
 void SoftwareUpdate::slotDownloadFinished(QNetworkReply *reply)
 {
- //qDebug() << "SoftwareUpdate::slotDownloadFinished"  << endl;
+    //qDebug() << "SoftwareUpdate::slotDownloadFinished"  << endl;
 
     QUrl url = reply->url();
-  //qDebug() << "SoftwareUpdate::slotDownloadFinished - URL: " << url.toString()  << endl;
+    //qDebug() << "SoftwareUpdate::slotDownloadFinished - URL: " << url.toString()  << endl;
 
     //QMessageBox msgBox;
     //QString aux;
@@ -78,7 +78,6 @@ void SoftwareUpdate::slotDownloadFinished(QNetworkReply *reply)
     if (reply->error())
     {
         //qDebug() << "SoftwareUpdate::slotDownloadFinished: reply error"  << endl;
-
     }
     else if (!redirectionTarget.isNull())
     {
@@ -87,15 +86,17 @@ void SoftwareUpdate::slotDownloadFinished(QNetworkReply *reply)
         //qDebug() << "SoftwareUpdate::slotDownloadFinished: Redirect: " << newUrl.toString() << endl;
         url = newUrl;
         reply->deleteLater();
-        setTheURL(url.toString());
-        connectToURL();
+        //request.setUrl(QUrl(url.toString()));
+        //setTheURL(url.toString());
+        connectToURL(url.toString());
         return;
     }
     else
     {
+        //qDebug() << "SoftwareUpdate::slotDownloadFinished: no redirection"  << endl;
         if (checkUpdates(reply))
         {
-          //qDebug() << "SoftwareUpdate::slotDownloadFinished checkupdates true"  << endl;
+            //qDebug() << "SoftwareUpdate::slotDownloadFinished checkupdates true"  << endl;
             if (repositoryFound)
             {
                 //qDebug() << "SoftwareUpdate::slotDownloadFinished repository found"  << endl;
@@ -113,6 +114,7 @@ void SoftwareUpdate::slotDownloadFinished(QNetworkReply *reply)
         {
             if (repositoryFound && messageShown)
             {
+                //qDebug() << "SoftwareUpdate::slotDownloadFinished checkupdates false!"  << endl;
                 updateDialog->setVersion(latestVersion, false);
                 updateDialog->show();
             }
@@ -123,6 +125,7 @@ void SoftwareUpdate::slotDownloadFinished(QNetworkReply *reply)
     }
 
     reply->deleteLater();
+    //manager->deleteLater();
     //qDebug() << "SoftwareUpdate::slotDownloadFinished end"  << endl;
 }
 
@@ -223,20 +226,23 @@ void SoftwareUpdate::needToUpdate(bool _showWithoutVersion)
     //qDebug() << "SoftwareUpdate::needToUpdate (current version: " << klogVersion  << ")"  << endl;
     messageShown = _showWithoutVersion;
     setVersion(klogVersion);
-    setTheURL("http://download.klog.xyz");
-    connectToURL();
-
-    //QNetworkReply *reply = manager->get(request);
-    //connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
-    //connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
-
+    //setTheURL("http://download.klog.xyz");
+    connectToURL("http://download.klog.xyz");
 }
 
 
-void SoftwareUpdate::connectToURL()
+void SoftwareUpdate::connectToURL(const QString _url)
 {
     // This is where the connection takes place.... so first connection may be the main URL but it launches connection after redirections
-    QNetworkReply *reply = manager->get(request);
+
+    QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+    //connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(replyFinished(QNetworkReply*)));
+
+    //request.setUrl(QUrl(_url));
+
+      manager->get(QNetworkRequest(QUrl(_url)));
+
+      QNetworkReply *reply = manager->get(request);
 
     connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
     connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
